==> gwenview-23.08.5.tar.xz: gwenview-23.08.5/part/gvpart.json.cmake <==
{
    "KPlugin": {
        "Icon": "gwenview",
        "InitialPreference": 12,
        "MimeTypes": [
            "${IMAGE_MIME_LIST}"
        ],
        "Name": "Gwenview Image Viewer",
        "Name[ar]": "جوِينفيو مستعرض الصورة",
        "Name[az]": "Gwenview şəkilə baxış aləti",
        "Name[bg]": "Програма за снимки Gwenview",
        "Name[ca@valencia]": "Visor d'imatges Gwenview",
        "Name[ca]": "Visualitzador d'imatges Gwenview",
        "Name[cs]": "Prohlížeč obrázků Gwenview",
        "Name[de]": "Gwenview Bildbetrachter",
        "Name[en_GB]": "Gwenview Image Viewer",
        "Name[eo]": "Gwenview Bildrigardilo",
        "Name[es]": "Visor de imágenes Gwenview",
        "Name[eu]": "Gwenview irudi erakuslea",
        "Name[fi]": "Gwenview-kuvakatselin",
        "Name[fr]": "Afficheur d'images Gwenview",
        "Name[gl]": "Visor de imaxes Gwenview",
        "Name[hu]": "Gwenview képmegjelenítő",
        "Name[ia]": "Visor de imagine Gwenview",
        "Name[id]": "Gwenview Penampil Gambar",
        "Name[it]": "Visore di immagini Gwenview",
        "Name[ka]": "Gwenview - სურათების დამთვალიერებელი",
        "Name[ko]": "Gwenview 그림 뷰어",
        "Name[nl]": "GWenview Afbeeldingenviewer",
        "Name[nn]": "Gwenview biletvisar",
        "Name[pl]": "Przeglądarka obrazów Gwenview",
        "Name[pt]": "Visualizador de Imagens Gwenview",
        "Name[pt_BR]": "Visualizador de imagens do Gwenview",
        "Name[ru]": "Программа просмотра изображений Gwenview",
        "Name[sk]": "Prehliadač obrázkov Gwenview",
        "Name[sl]": "Gwenview pregledovalnik slik",
        "Name[sv]": "Gwenview bildvisare",
        "Name[ta]": "குவென்வியூ படக் காட்டி",
        "Name[tr]": "Gwenview Görsel Görüntüleyicisi",
        "Name[uk]": "Переглядач зображень Gwenview",
        "Name[x-test]": "xxGwenview Image Viewerxx",
        "Name[zh_CN]": "Gwenview 图像查看器",
        "Name[zh_TW]": "Gwenview 影像檢視程式",
        "ServiceTypes": [
            "KParts/ReadOnlyPart"
        ]
    }
}

==> gwenview-24.01.75.tar.xz: gwenview-24.01.75/part/gvpart.json.cmake <==
{
    "KPlugin": {
        "Icon": "gwenview",
        "InitialPreference": 12,
        "MimeTypes": [
            "${IMAGE_MIME_LIST}"
        ],
        "Name": "Gwenview Image Viewer",
        "Name[ar]": "جوِينفيو مستعرض الصورة",
        "Name[az]": "Gwenview şəkilə baxış aləti",
        "Name[bg]": "Програма за снимки Gwenview",
        "Name[ca@valencia]": "Visor d'imatges Gwenview",
        "Name[ca]": "Visualitzador d'imatges Gwenview",
        "Name[cs]": "Prohlížeč obrázků Gwenview",
        "Name[de]": "Gwenview Bildbetrachter",
        "Name[el]": "Προβολέας εικόνων Gwenview",
        "Name[en_GB]": "Gwenview Image Viewer",
        "Name[eo]": "Gwenview Bildrigardilo",
        "Name[es]": "Visor de imágenes Gwenview",
        "Name[eu]": "Gwenview irudi erakuslea",
        "Name[fi]": "Gwenview-kuvakatselin",
        "Name[fr]": "Afficheur d'images Gwenview",
        "Name[gl]": "Visor de imaxes Gwenview",
        "Name[ia]": "Visor de imagine Gwenview",
        "Name[id]": "Gwenview Penampil Gambar",
        "Name[it]": "Visore di immagini Gwenview",
        "Name[ka]": "Gwenview - სურათების დამთვალიერებელი",
        "Name[ko]": "Gwenview 그림 뷰어",
        "Name[nl]": "GWenview Afbeeldingenviewer",
        "Name[nn]": "Gwenview biletvisar",
        "Name[pl]": "Przeglądarka obrazów Gwenview",
        "Name[pt]": "Visualizador de Imagens Gwenview",
        "Name[pt_BR]": "Visualizador de imagens do Gwenview",
        "Name[ru]": "Программа просмотра изображений Gwenview",
        "Name[sl]": "Gwenview pregledovalnik slik",
        "Name[sv]": "Gwenview bildvisare",
        "Name[ta]": "குவென்வியூ படக் காட்டி",
        "Name[tr]": "Akbakış Görsel Görüntüleyicisi",
        "Name[uk]": "Переглядач зображень Gwenview",
        "Name[x-test]": "xxGwenview Image Viewerxx",
        "Name[zh_CN]": "Gwenview 图像查看器",
        "Name[zh_TW]": "Gwenview 影像檢視程式",
        "ServiceTypes": [
            "KParts/ReadOnlyPart"
        ]
    }
}
